@@ -7,7 +7,7 @@
 #include <stdio.h>
 #include <math.h>
 /* #include <unistd.h> */
-#include <malloc.h>
+#include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 #include "utils.h"
